==> foundry_platform_sdk-0.84.0.tar.gz: foundry_platform_sdk-0.84.0/foundry/v2/datasets/errors/_create_transaction_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.datasets.models._branch_name import BranchName
from foundry.v2.datasets.models._dataset_rid import DatasetRid


class CreateTransactionPermissionDeniedParameters(TypedDict):
    """The provided token does not have permission to create a transaction on this dataset."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    branchName: NotRequired[BranchName]


@dataclass
class CreateTransactionPermissionDenied(PalantirRPCException):
    name: Literal["CreateTransactionPermissionDenied"]
    parameters: CreateTransactionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["CreateTransactionPermissionDenied"]

==> foundry_platform_sdk-0.98.0.tar.gz: foundry_platform_sdk-0.98.0/foundry/v2/datasets/errors/_create_transaction_permission_denied.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PermissionDeniedError
from foundry.v2.datasets.models._branch_name import BranchName
from foundry.v2.datasets.models._dataset_rid import DatasetRid


class CreateTransactionPermissionDeniedParameters(TypedDict):
    """The provided token does not have permission to create a transaction on this dataset."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    datasetRid: DatasetRid

    branchName: NotRequired[BranchName]


@dataclass
class CreateTransactionPermissionDenied(PermissionDeniedError):
    name: Literal["CreateTransactionPermissionDenied"]
    parameters: CreateTransactionPermissionDeniedParameters
    error_instance_id: str


__all__ = ["CreateTransactionPermissionDenied"]
